
# Welcome to your new Simmate project!



We also added the example_app to your ~/simmate/applications.yaml file.
If you ever want to remove or rename your apps, make sure you update this file too.
Also, make sure you install this project to your python path with...
pip install -e {project_name}
